==> cognito-1.60.0-sources.jar: software/amazon/awscdk/services/cognito/CfnUserPoolUICustomizationAttachmentProps.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Properties for defining a `AWS::Cognito::UserPoolUICustomizationAttachment`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooluicustomizationattachment.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.704Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.CfnUserPoolUICustomizationAttachmentProps")
@software.amazon.jsii.Jsii.Proxy(CfnUserPoolUICustomizationAttachmentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUserPoolUICustomizationAttachmentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Cognito::UserPoolUICustomizationAttachment.ClientId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooluicustomizationattachment.html#cfn-cognito-userpooluicustomizationattachment-clientid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getClientId();

    /**
     * `AWS::Cognito::UserPoolUICustomizationAttachment.UserPoolId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooluicustomizationattachment.html#cfn-cognito-userpooluicustomizationattachment-userpoolid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserPoolId();

    /**
     * `AWS::Cognito::UserPoolUICustomizationAttachment.CSS`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-userpooluicustomizationattachment.html#cfn-cognito-userpooluicustomizationattachment-css
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCss() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnUserPoolUICustomizationAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUserPoolUICustomizationAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUserPoolUICustomizationAttachmentProps> {
        private java.lang.String clientId;
        private java.lang.String userPoolId;
        private java.lang.String css;

        /**
         * Sets the value of {@link CfnUserPoolUICustomizationAttachmentProps#getClientId}
         * @param clientId `AWS::Cognito::UserPoolUICustomizationAttachment.ClientId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clientId(java.lang.String clientId) {
            this.clientId = clientId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolUICustomizationAttachmentProps#getUserPoolId}
         * @param userPoolId `AWS::Cognito::UserPoolUICustomizationAttachment.UserPoolId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userPoolId(java.lang.String userPoolId) {
            this.userPoolId = userPoolId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolUICustomizationAttachmentProps#getCss}
         * @param css `AWS::Cognito::UserPoolUICustomizationAttachment.CSS`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder css(java.lang.String css) {
            this.css = css;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUserPoolUICustomizationAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUserPoolUICustomizationAttachmentProps build() {
            return new Jsii$Proxy(clientId, userPoolId, css);
        }
    }

    /**
     * An implementation for {@link CfnUserPoolUICustomizationAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUserPoolUICustomizationAttachmentProps {
        private final java.lang.String clientId;
        private final java.lang.String userPoolId;
        private final java.lang.String css;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clientId = this.jsiiGet("clientId", java.lang.String.class);
            this.userPoolId = this.jsiiGet("userPoolId", java.lang.String.class);
            this.css = this.jsiiGet("css", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String clientId, final java.lang.String userPoolId, final java.lang.String css) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clientId = java.util.Objects.requireNonNull(clientId, "clientId is required");
            this.userPoolId = java.util.Objects.requireNonNull(userPoolId, "userPoolId is required");
            this.css = css;
        }

        @Override
        public java.lang.String getClientId() {
            return this.clientId;
        }

        @Override
        public java.lang.String getUserPoolId() {
            return this.userPoolId;
        }

        @Override
        public java.lang.String getCss() {
            return this.css;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clientId", om.valueToTree(this.getClientId()));
            data.set("userPoolId", om.valueToTree(this.getUserPoolId()));
            if (this.getCss() != null) {
                data.set("css", om.valueToTree(this.getCss()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.CfnUserPoolUICustomizationAttachmentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUserPoolUICustomizationAttachmentProps.Jsii$Proxy that = (CfnUserPoolUICustomizationAttachmentProps.Jsii$Proxy) o;

            if (!clientId.equals(that.clientId)) return false;
            if (!userPoolId.equals(that.userPoolId)) return false;
            return this.css != null ? this.css.equals(that.css) : that.css == null;
        }

        @Override
        public int hashCode() {
            int result = this.clientId.hashCode();
            result = 31 * result + (this.userPoolId.hashCode());
            result = 31 * result + (this.css != null ? this.css.hashCode() : 0);
            return result;
        }
    }
}

==> cognito-1.93.0-sources.jar: software/amazon/awscdk/services/cognito/CfnUserPoolUICustomizationAttachmentProps.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Properties for defining a `AWS::Cognito::UserPoolUICustomizationAttachment`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.468Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.CfnUserPoolUICustomizationAttachmentProps")
@software.amazon.jsii.Jsii.Proxy(CfnUserPoolUICustomizationAttachmentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUserPoolUICustomizationAttachmentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Cognito::UserPoolUICustomizationAttachment.ClientId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getClientId();

    /**
     * `AWS::Cognito::UserPoolUICustomizationAttachment.UserPoolId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserPoolId();

    /**
     * `AWS::Cognito::UserPoolUICustomizationAttachment.CSS`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCss() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnUserPoolUICustomizationAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUserPoolUICustomizationAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUserPoolUICustomizationAttachmentProps> {
        private java.lang.String clientId;
        private java.lang.String userPoolId;
        private java.lang.String css;

        /**
         * Sets the value of {@link CfnUserPoolUICustomizationAttachmentProps#getClientId}
         * @param clientId `AWS::Cognito::UserPoolUICustomizationAttachment.ClientId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clientId(java.lang.String clientId) {
            this.clientId = clientId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolUICustomizationAttachmentProps#getUserPoolId}
         * @param userPoolId `AWS::Cognito::UserPoolUICustomizationAttachment.UserPoolId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userPoolId(java.lang.String userPoolId) {
            this.userPoolId = userPoolId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserPoolUICustomizationAttachmentProps#getCss}
         * @param css `AWS::Cognito::UserPoolUICustomizationAttachment.CSS`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder css(java.lang.String css) {
            this.css = css;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUserPoolUICustomizationAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUserPoolUICustomizationAttachmentProps build() {
            return new Jsii$Proxy(clientId, userPoolId, css);
        }
    }

    /**
     * An implementation for {@link CfnUserPoolUICustomizationAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUserPoolUICustomizationAttachmentProps {
        private final java.lang.String clientId;
        private final java.lang.String userPoolId;
        private final java.lang.String css;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clientId = software.amazon.jsii.Kernel.get(this, "clientId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.userPoolId = software.amazon.jsii.Kernel.get(this, "userPoolId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.css = software.amazon.jsii.Kernel.get(this, "css", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String clientId, final java.lang.String userPoolId, final java.lang.String css) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clientId = java.util.Objects.requireNonNull(clientId, "clientId is required");
            this.userPoolId = java.util.Objects.requireNonNull(userPoolId, "userPoolId is required");
            this.css = css;
        }

        @Override
        public final java.lang.String getClientId() {
            return this.clientId;
        }

        @Override
        public final java.lang.String getUserPoolId() {
            return this.userPoolId;
        }

        @Override
        public final java.lang.String getCss() {
            return this.css;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clientId", om.valueToTree(this.getClientId()));
            data.set("userPoolId", om.valueToTree(this.getUserPoolId()));
            if (this.getCss() != null) {
                data.set("css", om.valueToTree(this.getCss()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.CfnUserPoolUICustomizationAttachmentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUserPoolUICustomizationAttachmentProps.Jsii$Proxy that = (CfnUserPoolUICustomizationAttachmentProps.Jsii$Proxy) o;

            if (!clientId.equals(that.clientId)) return false;
            if (!userPoolId.equals(that.userPoolId)) return false;
            return this.css != null ? this.css.equals(that.css) : that.css == null;
        }

        @Override
        public final int hashCode() {
            int result = this.clientId.hashCode();
            result = 31 * result + (this.userPoolId.hashCode());
            result = 31 * result + (this.css != null ? this.css.hashCode() : 0);
            return result;
        }
    }
}
